auxLine2 property
Line 2 of the street address. It is an arbitrary text string that does not describe the street itself.
Implementation
final String? auxLine2;
Line 2 of the street address. It is an arbitrary text string that does not describe the street itself.
final String? auxLine2;